// SPDX-FileCopyrightText: 2024 Manuel Alcaraz Zambrano <manuelalcarazzam@gmail.com>
// SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL

#pragma once

#include <KUnitConversion/Converter>
#include <KUnitConversion/Unit>
#include <KUnitConversion/UnitCategory>
#include <KUnitConversion/Value>
